import { FormattingOptions } from './FormattingOptions';
export declare class BrightScriptFormatter {
    constructor();
    /**
     * The default number of spaces when indenting with spaces
     */
    private static DEFAULT_INDENT_SPACE_COUNT;
    /**
     * Format the given input.
     * @param inputText the text to format
     * @param formattingOptions options specifying formatting preferences
     */
    format(inputText: string, formattingOptions?: FormattingOptions): string;
    /**
     * Remove all whitespace in the composite keyword tokens with a single space
     * @param tokens
     */
    private normalizeCompositeKeywords;
    private dedupeWhitespace;
    private formatCompositeKeywords;
    private getCompositeKeywordParts;
    /**
     * Determine if the token is a type keyword (meaing preceeded by `as` token)
     * @param token
     */
    private isType;
    private formatKeywordCase;
    private formatIndentation;
    /**
     * Force all whitespace between tokens to be exactly 1 space wide
     */
    private formatInteriorWhitespace;
    /**
     * Remove whitespace tokens backwards until a non-whitespace token is encountered
     * @param startIndex the index of the non-whitespace token to start with. This function will start iterating at `startIndex - 1`
     */
    private removeWhitespaceTokensBackwards;
    /**
     * Remove whitespace until the next non-whitespace character.
     * This operates on the array itself
     */
    private removeWhitespace;
    /**
     * Anytime one of these tokens are found before a minus sign,
     * we can safely assume the minus sign is associated with a negative numeric literal
     */
    private static tokensBeforeNegativeNumericLiteral;
    /**
     * Determine if the current token appears to be the negative sign for a numeric leteral
     */
    private looksLikeNegativeNumericLiteral;
    /**
     * Get the first token after the index that is NOT whitespace
     */
    private getNextNonWhitespaceToken;
    /**
     * Get the first token before the index that is NOT whitespace
     */
    private getPreviousNonWhitespaceToken;
    /**
     * Remove all trailing whitespace
     */
    private formatTrailingWhiteSpace;
    private tokenIndexOf;
    /**
     * Get the tokens for the whole line starting at the given index (including the newline or EOF token at the end)
     * @param startIndex
     * @param tokens
     */
    private getLineTokens;
    private normalizeOptions;
    private isSingleLineIfStatement;
}
